import socket
from typing import List

def load_default_ports(path='assets/common_1k_ports.txt') -> List[int]:
    try:
        with open(path, 'r') as f:
            return [int(p) for p in f.read().split(',') if p.strip().isdigit()]
    except (FileNotFoundError, ValueError):
        return [80, 443, 8080]  # Fallback

def scan_port(ip: str, port: int, timeout: float = 0.5) -> bool:
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
            sock.settimeout(timeout)
            return sock.connect_ex((ip, port)) == 0
    except Exception:
        return False
    
def parse_ports(range_str: str) -> List[int]:
    ports = []
    parts = range_str.split(',')
    for part in parts:
        if "-" in part:
            try:
                start, end = map(int, part.split('-'))
                if start > end:
                    tmp = start
                    start = end
                    end = tmp
                ports.extend(range(start, end + 1))
            except ValueError:
                raise ValueError(f"Invalid range format: {part}")
        elif part.isdigit():
            ports.append(int(part))
        else:
            raise ValueError(f"Invalid port format: {part}")
    return list(set(ports))
